@@ -7,16 +7,13 @@ our $AUTOLOAD;
 sub new {
     my ($class, $args) = @_;
 
-    my $self = bless {
+    bless {
+        select_columns     => [keys %{$args->{row_data}}],
+        table              => $args->{teng}->schema->get_table($args->{table_name}),
         _get_column_cached => {},
         _dirty_columns     => {},
         %$args,
     }, $class;
-
-    $self->{select_columns} ||= [keys %{$args->{row_data}}];
-    $self->{table} ||= $args->{teng}->schema->get_table($args->{table_name});
-
-    $self;
 }
 
 sub _lazy_get_data {
@@ -49,7 +46,7 @@ sub get_column {
     if ( exists $self->{row_data}->{$col} ) {
         return $self->{row_data}->{$col};
     } else {
-        Carp::croak("Specified colum '$col' not found in row (query: " . ( $self->{sql} || 'unknown' ) . ")" );
+        Carp::croak("$col no selected column. SQL: " . ( $self->{sql} || 'unknown' ) );
     }
 }
 
@@ -71,7 +68,7 @@ sub set_column {
     }
 
     $self->{row_data}->{$col} = $val;
-    delete $self->{_get_column_cached}->{$col};
+    $self->{_get_column_cached}->{$col} = $val;
     $self->{_dirty_columns}->{$col} = 1;
 }
 
@@ -99,28 +96,8 @@ sub update {
         Carp::croak q{can't update from basic Teng::Row class.};
     }
 
-    my $table      = $self->{table};
-    my $table_name = $self->{table_name};
-    if (! $table) {
-        Carp::croak( "Table definition for $table_name does not exist (Did you declare it in our schema?)" );
-    }
-
-    %$upd = (%{$self->get_dirty_columns}, %{$upd||+{}});
-    for my $col (keys %{$upd}) {
-       $upd->{$col} = $table->call_deflate($col, $upd->{$col});
-    }
-
-    my $where = $self->_where_cond;
     $self->set_columns($upd);
-
-    $upd = $self->get_dirty_columns;
-    return 0 unless %$upd;
-
-    my $bind_args = $self->{teng}->_bind_sql_type_to_args($table, $upd);
-    my $result = $self->{teng}->_update($table_name, $bind_args, $where, 1);
-    $self->{_dirty_columns} = {};
-
-    $result;
+    $self->{teng}->update($self->{table_name}, $self->get_dirty_columns, $self->_where_cond($self->{table_name}));
 }
 
 sub delete {
@@ -130,19 +107,18 @@ sub delete {
         Carp::croak q{can't delete from basic Teng::Row class.};
     }
 
-    $self->{teng}->delete($self->{table_name}, $self->_where_cond);
+    $self->{teng}->delete($self->{table_name}, $self->_where_cond($self->{table_name}));
 }
 
 sub refetch {
     my $self = shift;
-    $self->{teng}->single($self->{table_name}, $self->_where_cond);
+    $self->{teng}->single($self->{table_name}, $self->_where_cond($self->{table_name}));
 }
 
 sub _where_cond {
-    my $self = shift;
+    my ($self, $table_name) = @_;
 
-    my $table      = $self->{table};
-    my $table_name = $self->{table_name};
+    my $table = $self->{teng}->schema->get_table( $table_name );
     unless ($table) {
         Carp::croak("Unknown table: $table_name");
     }
