@@ -6,7 +6,6 @@ use Class::Accessor::Lite
         name
         primary_keys
         columns
-        escaped_columns
         sql_types
         row_class
     ) ]
@@ -17,9 +16,6 @@ use Class::Load ();
 sub new {
     my ($class, %args) = @_;
     my $self = bless {
-        deflators       => [],
-        inflators       => [],
-        escaped_columns => {},
         %args
     }, $class;
 
@@ -45,77 +41,41 @@ sub get_sql_type {
     $self->sql_types->{ $column_name };
 }
 
-sub add_deflator {
-    my ($self, $rule, $code) = @_;
-    if ( ref $rule ne 'Regexp' ) {
-        $rule = qr/^\Q$rule\E$/;
-    }
+sub get_deflator { $_[0]->{deflators}->{$_[1]} }
+sub get_inflator { $_[0]->{inflators}->{$_[1]} }
+sub set_deflator {
+    my ($self, $col, $code) = @_;
+
     unless (ref($code) eq 'CODE') {
         Carp::croak('deflate code must be coderef.');
     }
-    push @{ $self->{deflators} }, ( $rule, $code );
+    $self->{deflators}->{$col} = $code;
 }
+sub set_inflator {
+    my ($self, $col, $code) = @_;
 
-sub add_inflator {
-    my ($self, $rule, $code) = @_;
-    if ( ref $rule ne 'Regexp' ) {
-        $rule = qr/^\Q$rule\E$/;
-    }
     unless (ref($code) eq 'CODE') {
-        Carp::croak('inflate code must be coderef.');
+        Carp::croak('deflate code must be coderef.');
     }
-    push @{ $self->{inflators} }, ( $rule, $code );
+    $self->{inflators}->{$col} = $code;
 }
 
 sub call_deflate {
     my ($self, $col_name, $col_value) = @_;
-    my $rules = $self->{deflators};
-    my $i = 0;
-    my $max = @$rules;
-    while ( $i < $max ) {
-        my ($rule, $code) = @$rules[ $i, $i + 1 ];
-        if ($col_name =~ /$rule/) {
-            return $code->($col_value);
-        }
-        $i += 2;
+    if (my $code = $self->get_deflator( $col_name )) {
+        return $code->($col_value);
     }
     return $col_value;
 }
 
 sub call_inflate {
     my ($self, $col_name, $col_value) = @_;
-    my $rules = $self->{inflators};
-    my $i = 0;
-    my $max = @$rules;
-    while ( $i < $max ) {
-        my ($rule, $code) = @$rules[ $i, $i + 1 ];
-        if ($col_name =~ /$rule/) {
-            return $code->($col_value);
-        }
-        $i += 2;
+    if (my $code = $self->get_inflator( $col_name )) {
+        return $code->($col_value);
     }
     return $col_value;
 }
 
-sub has_deflators {
-    my $self = shift;
-    return scalar @{ $self->{deflators} };
-}
-
-sub has_inflators {
-    my $self = shift;
-    return scalar @{ $self->{inflators} };
-}
-
-sub prepare_from_dbh {
-    my ($self, $dbh) = @_;
-
-    $self->escaped_columns->{$dbh->{Driver}->{Name}} ||= [
-        map { \$dbh->quote_identifier($_) }
-        @{$self->columns}
-    ];
-}
-
 1;
 
 __END__
@@ -128,9 +88,9 @@ Teng::Schema::Table - Teng table class.
 
 =over 4
 
-=item $table = Teng::Schema::Table->new
+=item $table = Teng::Table->new
 
-create new Teng::Schema::Table's object.
+create new Teng::Table's object.
 
 =item $table->get_sql_type
 
@@ -160,12 +120,4 @@ execute deflate.
 
 execute inflate.
 
-=item $table->has_deflators()
-
-Returns true if there are any deflators
-
-=item $table->has_inflators();
-
-Returns true if there are any inflators
-
 =back
